#
# spec file for package python-immutabledict
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%define         short_name immutabledict
%{?sle15_python_module_pythons}
Name:           python-%{short_name}%{psuffix}
Version:        4.2.0
Release:        1.2
Summary:        Immutable wrapper around dictionaries (a fork of frozendict)
License:        MIT
URL:            https://github.com/corenting/immutabledict
Source:         https://files.pythonhosted.org/packages/source/i/immutabledict/immutabledict-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing_extensions}
BuildRequires:  %{python_module wheel}
%if %{with test}
BuildRequires:  %{python_module pytest}
%endif
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module %{short_name} = %version}
%endif
%python_subpackages

%description
A fork of the original frozendict, an immutable wrapper around dictionaries. This library is a pure Python, MIT-licensed alternative to the new LGPL-3.0 licensed frozendict.

It implements the complete mapping interface and can be used as a drop-in replacement for dictionaries where immutability is desired. The immutabledict constructor mimics dict, and all of the expected interfaces (iter, len, repr, hash, getitem) are provided. Note that an immutabledict does not guarantee the immutability of its values, so the utility of hash method is restricted by usage.

The only difference is that the copy() method of immutable takes variable keyword arguments, which will be present as key/value pairs in the new, immutable copy.

%prep
%setup -q -n %{short_name}-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/%{short_name}
%{python_sitelib}/%{short_name}-%{version}.dist-info
%endif

%changelog
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 4.2.0:
  * Add `discard` method which return a new immutabledict without
    the item at the given key, if present
* Mon Feb 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Use pytest to run the testsuite.
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 4.1.0:
  * Do not store cached hash value when pickling
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.0:
  * Replace `__init__` by `__new__`.
  * Add explicit items()/keys()/values() methods to speedup these
    methods.
  * Add set/delete/update functions.
  * Add documentation at immutabledict.corenting.fr
* Thu Aug 10 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.0:
  * copy() (breaking change): remove the option to pass keyword
    arguments (which were present as key/value pairs in the copy).
    Now the method doesn't take any arguments (it behaves the same
    as a normal dict).
  * Python versions: drop Python 3.7 support
  * Typing: fixes
  - Make the key covariant. Thanks to @spacether for the PR #244
  - Fix key/value typing missing for ImmutableOrderedDict
* Mon Jul 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Jul  6 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.5:
  * Fix hard-coded class reference in fromkeys() resulting in
    always using `dict` for `fromkeys()` (instead of OrderedDict
    in ImmutableOrderedDict for example)
* Sat Apr  8 2023 Marcus Rueckert <mrueckert@suse.de>
- initial package
